# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class IApp(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, description=None, devicegroup=None, execute_action=None, inherited_devicegroup=None, inherited_traffic_group=None, jsonfile=None, lists=None, metadatas=None, name=None, partition=None, strict_updates=None, tables=None, template=None, template_modified=None, template_prerequisite_errors=None, traffic_group=None, variables=None):
        """Create a IApp resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['description'] = description

        __props__['devicegroup'] = devicegroup

        __props__['execute_action'] = execute_action

        __props__['inherited_devicegroup'] = inherited_devicegroup

        __props__['inherited_traffic_group'] = inherited_traffic_group

        __props__['jsonfile'] = jsonfile

        __props__['lists'] = lists

        __props__['metadatas'] = metadatas

        __props__['name'] = name

        __props__['partition'] = partition

        __props__['strict_updates'] = strict_updates

        __props__['tables'] = tables

        __props__['template'] = template

        __props__['template_modified'] = template_modified

        __props__['template_prerequisite_errors'] = template_prerequisite_errors

        __props__['traffic_group'] = traffic_group

        __props__['variables'] = variables

        super(IApp, __self__).__init__(
            'f5bigip:sys/iApp:IApp',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class PersistenceProfileDstAddr(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, app_service=None, defaults_from=None, hash_algorithm=None, mask=None, match_across_pools=None, match_across_services=None, match_across_virtuals=None, mirror=None, name=None, override_conn_limit=None, timeout=None):
        """Create a PersistenceProfileDstAddr resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['app_service'] = app_service

        if not defaults_from:
            raise TypeError('Missing required property defaults_from')
        __props__['defaults_from'] = defaults_from

        __props__['hash_algorithm'] = hash_algorithm

        __props__['mask'] = mask

        __props__['match_across_pools'] = match_across_pools

        __props__['match_across_services'] = match_across_services

        __props__['match_across_virtuals'] = match_across_virtuals

        __props__['mirror'] = mirror

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['override_conn_limit'] = override_conn_limit

        __props__['timeout'] = timeout

        super(PersistenceProfileDstAddr, __self__).__init__(
            'f5bigip:ltm/persistenceProfileDstAddr:PersistenceProfileDstAddr',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class Monitor(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, defaults_from=None, destination=None, interval=None, ip_dscp=None, manual_resume=None, name=None, parent=None, receive=None, receive_disable=None, reverse=None, send=None, time_until_up=None, timeout=None, transparent=None):
        """Create a Monitor resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['defaults_from'] = defaults_from

        __props__['destination'] = destination

        __props__['interval'] = interval

        __props__['ip_dscp'] = ip_dscp

        __props__['manual_resume'] = manual_resume

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        if not parent:
            raise TypeError('Missing required property parent')
        __props__['parent'] = parent

        __props__['receive'] = receive

        __props__['receive_disable'] = receive_disable

        __props__['reverse'] = reverse

        __props__['send'] = send

        __props__['time_until_up'] = time_until_up

        __props__['timeout'] = timeout

        __props__['transparent'] = transparent

        super(Monitor, __self__).__init__(
            'f5bigip:ltm/monitor:Monitor',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class SnmpTraps(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, auth_passwordencrypted=None, auth_protocol=None, community=None, description=None, engine_id=None, host=None, name=None, port=None, privacy_password=None, privacy_password_encrypted=None, privacy_protocol=None, security_level=None, security_name=None, version=None):
        """Create a SnmpTraps resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['auth_passwordencrypted'] = auth_passwordencrypted

        __props__['auth_protocol'] = auth_protocol

        __props__['community'] = community

        __props__['description'] = description

        __props__['engine_id'] = engine_id

        __props__['host'] = host

        __props__['name'] = name

        __props__['port'] = port

        __props__['privacy_password'] = privacy_password

        __props__['privacy_password_encrypted'] = privacy_password_encrypted

        __props__['privacy_protocol'] = privacy_protocol

        __props__['security_level'] = security_level

        __props__['security_name'] = security_name

        __props__['version'] = version

        super(SnmpTraps, __self__).__init__(
            'f5bigip:sys/snmpTraps:SnmpTraps',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class SelfIp(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, ip=None, name=None, traffic_group=None, vlan=None):
        """Create a SelfIp resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        if not ip:
            raise TypeError('Missing required property ip')
        __props__['ip'] = ip

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['traffic_group'] = traffic_group

        if not vlan:
            raise TypeError('Missing required property vlan')
        __props__['vlan'] = vlan

        super(SelfIp, __self__).__init__(
            'f5bigip:net/selfIp:SelfIp',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class ProfileHttp2(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, activation_modes=None, concurrent_streams_per_connection=None, connection_idle_timeout=None, defaults_from=None, header_table_size=None, name=None):
        """Create a ProfileHttp2 resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['activation_modes'] = activation_modes

        __props__['concurrent_streams_per_connection'] = concurrent_streams_per_connection

        __props__['connection_idle_timeout'] = connection_idle_timeout

        __props__['defaults_from'] = defaults_from

        __props__['header_table_size'] = header_table_size

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        super(ProfileHttp2, __self__).__init__(
            'f5bigip:ltm/profileHttp2:ProfileHttp2',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class VirtualServer(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, client_profiles=None, destination=None, fallback_persistence_profile=None, ip_protocol=None, irules=None, mask=None, name=None, persistence_profiles=None, policies=None, pool=None, port=None, profiles=None, server_profiles=None, snatpool=None, source=None, source_address_translation=None, translate_address=None, translate_port=None, vlans=None, vlans_enabled=None):
        """Create a VirtualServer resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['client_profiles'] = client_profiles

        if not destination:
            raise TypeError('Missing required property destination')
        __props__['destination'] = destination

        __props__['fallback_persistence_profile'] = fallback_persistence_profile

        __props__['ip_protocol'] = ip_protocol

        __props__['irules'] = irules

        __props__['mask'] = mask

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['persistence_profiles'] = persistence_profiles

        __props__['policies'] = policies

        __props__['pool'] = pool

        if not port:
            raise TypeError('Missing required property port')
        __props__['port'] = port

        __props__['profiles'] = profiles

        __props__['server_profiles'] = server_profiles

        __props__['snatpool'] = snatpool

        __props__['source'] = source

        __props__['source_address_translation'] = source_address_translation

        __props__['translate_address'] = translate_address

        __props__['translate_port'] = translate_port

        __props__['vlans'] = vlans

        __props__['vlans_enabled'] = vlans_enabled

        super(VirtualServer, __self__).__init__(
            'f5bigip:ltm/virtualServer:VirtualServer',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

